@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-b1074b7449e579a115e65249a9ac6f7e
-key: yesod_JkQJdzar399FMkIHfAauSA
+id: yesod-1.4.2-84d671f4a4813d5e21773c05bb378267
+key: yesod_9btgpqWEDkb2qUgVKrBLcH
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,9 +21,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-JkQJdzar399FMkIHfAauSA
+hs-libraries: HSyesod-1.4.2-9btgpqWEDkb2qUgVKrBLcH
 depends:
-    aeson-0.11.0.0-3b69ab8a9952fc7c94fde12b431d717b
+    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
@@ -36,7 +36,7 @@ depends:
     monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    shakespeare-2.0.7-eabbf817e7dec503c762bf3ca866120e
+    shakespeare-2.0.7-299569683f963ce6b42dbe4d7cdb1dae
     streaming-commons-0.1.15.1-aa72527d91e580265833d7825d2659ed
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-extra-3.0.13.1-22d19709bfcccb29f4594bf354c81852
+    wai-extra-3.0.14.1-048a6fe5f08082cf473c90446f630ef3
     wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
-    warp-3.2.3-2ffba1d488a66a20d1493710458a6854
-    yaml-0.8.16-fb65281075453c8e8a8a864f3d81487b
-    yesod-auth-1.4.12-9c0846a8a225735e3c282069bef3d15a
-    yesod-core-1.4.19-25291e79c5b81358b9ac81b70c6e2fbf
-    yesod-form-1.4.6-285f2c95c28be4abb135ef468c7f72ca
-    yesod-persistent-1.4.0.3-18c5d3615cff02a6885ec3f5b19c7c3f
+    warp-3.2.3-0572492b8a7d95a6249d079a8975f899
+    yaml-0.8.16-6c308454b5ac62fa4195e7f56277be05
+    yesod-auth-1.4.12-ee3d41f28307a05c0f72f6763eadee03
+    yesod-core-1.4.19-25fb856b7d20f03518ef74f7c04b9148
+    yesod-form-1.4.6-1f5bbab0daee91a31c9792276fdb63be
+    yesod-persistent-1.4.0.3-94cd901c0d8cf92080c629833de6573c
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
